![Site Configs CI](https://github.com/renderbox/django-site-settings/workflows/Site%20Configs%20CI/badge.svg)

![Site Configs CI](https://github.com/renderbox/django-site-settings/workflows/Site%20Configs%20Develop/badge.svg)

# Site Configs

A Django app that manages configurations per-site on a multi-site setup.  These settings can be made avaialble to users of different sites or administerd via the Django admin.
